@@ -22,7 +22,7 @@ from vkbottle_types.objects import (
     MessagesPinnedMessage,
     MessagesSendUserIdsResponseItem,
     UsersUser,
-    UsersUserFull
+    UsersUserFull,
 )
 
 
@@ -174,10 +174,6 @@ class SendUserIdsResponse(BaseResponse):
     response: typing.List["MessagesSendUserIdsResponseItem"] = None
 
 
-class SendPeerIdsResponse(SendUserIdsResponse):
-    pass
-
-
 class SetChatPhotoResponse(BaseResponse):
     response: "SetChatPhotoResponseModel" = None
 
